//
//  WWGraphView.m
//  WWGraph
//
//  Created by Robby Weinberg on 9/27/09.
//  Copyright 2009. All rights reserved.
//

#import "WWGraphView.h"

#define BORDER_SIZE 6

@interface WWGraphView (Private)

- (void)drawTitle;
- (void)drawXTitle;
- (void)drawYTitle;
- (void)drawGraph;

@end



@implementation WWGraphView

- (void)drawRect:(NSRect)rect
{
	[self drawTitle];
	[self drawXTitle];
	[self drawYTitle];
	[self drawGraph];
}

#pragma mark Part Drawing
	 
- (void)drawTitle
{
	if(title && [title length] > 0){
		NSRect ctrlRect = [self frame];
		NSAttributedString *string = [[NSAttributedString alloc] initWithString:title attributes:[NSDictionary dictionaryWithObjectsAndKeys:
																								  [NSFont fontWithName:@"Helvetica" size:16.0], NSFontAttributeName,
																								  nil]];
		if ([string size].width > ctrlRect.size.width) {
			//Title not drawn if it is too long
			return;
		}
		ctrlRect.origin.x = ([self frame].size.width - [string size].width)/2;
		ctrlRect.origin.y = [self frame].size.height - BORDER_SIZE - [string size].height;
		ctrlRect.size.height = [string size].height;
		[string drawInRect:ctrlRect];
		[string release];
	}
}

- (void)drawXTitle
{
	if (xtitle && [title length] > 0) {
		NSRect ctrlRect = [self frame];
		NSAttributedString *string = [[NSAttributedString alloc] initWithString:xtitle attributes:[NSDictionary dictionaryWithObjectsAndKeys:
																								   [NSFont fontWithName:@"Helvetica" size:14], NSFontAttributeName,
																								   nil]];
		if([string size].width > ctrlRect.size.width){
			NSLog(@"?");
			return;
		}
		ctrlRect.origin.x = ([self frame].size.width - [string size].width)/2;
		ctrlRect.origin.y = BORDER_SIZE; //Check
		ctrlRect.size.height = [string size].height;
		[string drawInRect:ctrlRect];
		[string release];
	}
}

- (void)drawYTitle
{
	NSRect ctrlRect = [self frame];
	NSAttributedString *string = [[NSAttributedString alloc] initWithString:ytitle attributes:[NSDictionary dictionaryWithObjectsAndKeys:
																							   [NSFont fontWithName:@"Helvetica" size:14], NSFontAttributeName,
																							   nil]];
	if([string size].width > ctrlRect.size.height){
		return;
	}
	
	NSAffineTransform *transform = [NSAffineTransform transform];
	NSGraphicsContext *context = [NSGraphicsContext currentContext];
	
	
	[transform rotateByDegrees:90];
	
	[context saveGraphicsState];
	[transform concat];
	[[NSColor blueColor] set];
	[string drawInRect:NSMakeRect((ctrlRect.size.height - [string size].width)/2, -BORDER_SIZE-[string size].height, [string size].width, [string size].height)];
	[context restoreGraphicsState];
	[string release];
}

- (void)drawGraph
{
	NSRect ctrlRect = [self frame];
	
	//give margins from the edge of the window to draw graph
	ctrlRect = NSInsetRect(ctrlRect, BORDER_SIZE, BORDER_SIZE);
	
	//make margins even larger if titles are present
	ctrlRect.size.height -= ((title && [title length] > 0) ? 16 + BORDER_SIZE : 0);
	if(xtitle && [xtitle length] > 0){
		ctrlRect.size.height -= 16 + BORDER_SIZE;
		ctrlRect.origin.y += 16 + BORDER_SIZE;
	}
	if(ytitle && [ytitle length] >0){
//XXX 16 might not be good here because text is being drawn vertically.
		ctrlRect.size.width -= 16 + BORDER_SIZE;
		ctrlRect.origin.x += 16 + BORDER_SIZE;
	}
	   
	[[NSColor cyanColor] set];
	NSRectFill(ctrlRect);
}

@synthesize title, xtitle, ytitle;

@end
